@@ -1603,7 +1603,6 @@ void AAptInterface::removeFromBlacklist(Package *pkg, BlacklistSelect::blackList
 		return;
 	}
 
-	//QStringList newlist;
 	bool removed = false;
 
 	for( int i=0; i<iBlacklist.count(); i++ )
@@ -1622,20 +1621,6 @@ void AAptInterface::removeFromBlacklist(Package *pkg, BlacklistSelect::blackList
 				removed = true;
 			}
 		}
-
-		/*
-		if( oldstate == BlacklistSelect::BlacklistAll )
-		{
-			if( !(iBlacklist.at(i) == pkg->name()) ) {
-				newlist << iBlacklist.at(i);
-			} else removed = true;
-		} else if( oldstate == BlacklistSelect::BlacklistThis ) {
-			if( !(iBlacklist.at(i) == (pkg->name()+" "+pkg->version())) ) {
-				newlist << iBlacklist.at(i);
-			} else removed = true;
-		} else {
-			newlist << iBlacklist.at(i);
-		}*/
 	}
 
 	if( removed )
@@ -1643,7 +1628,6 @@ void AAptInterface::removeFromBlacklist(Package *pkg, BlacklistSelect::blackList
 	else
 		qDebug() << "blacklist:" << pkg->name() << "not in saved list";
 
-	//iBlacklist = newlist;
 }
 
 
@@ -1970,10 +1954,3 @@ void AAptInterface::readPinnedPackages()
 								  "remove such settings as they can result in unexpected behavior of Faster Application Manager.");
 	}
 }
-
-bool AAptInterface::loadInstallFiles(QStringList files_)
-{
-	qDebug() << files_;
-
-	return false;
-}
