@@ -54,3 +54,8 @@ void ConfirmDialog::setText(QString title, QString text)
 	ui->label->setText(text);
 	this->adjustSize();
 }
+
+void ConfirmDialog::disableButton()
+{
+	ui->btn_OK->setEnabled(false);
+}
